@@ -88,14 +88,14 @@ unless ($opts{z}) {
 my $VcArchDir;
 my $DiffProgram;
 {
-    my $rdr = XML::Reader->newhd($cnst_VcParam, {filter => 5},
+    my $rdr = XML::Reader->new($cnst_VcParam, {mode => 'branches'},
       {root => '/vc/archive',  branch => ['/@path']},
       {root => '/vc/difftool', branch => ['/@prog']},
-    ) or die "Error-0010: Can't XML::Reader->newhd('$cnst_VcParam') because $!";
+    ) or die "Error-0010: Can't XML::Reader->new('$cnst_VcParam') because $!";
 
     while ($rdr->iterate) {
-        if ($rdr->rx == 0) { $VcArchDir   = $rdr->rvalue->[0]; }
-        if ($rdr->rx == 1) { $DiffProgram = $rdr->rvalue->[0]; } # Don't worry about $DiffProgram
+        if ($rdr->rx == 0) { ($VcArchDir)   = $rdr->value; }
+        if ($rdr->rx == 1) { ($DiffProgram) = $rdr->value; } # Don't worry about $DiffProgram
     }
 }
 
